==> dl.php?src=linea21_2_5_0.zip: linea21/workshop/help.php <==
<?php
/**
 * Workshop module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\workshop
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add');?></p>
<ul>
	<li><?php echo _t('workshop','help_add1');?></li>
	<li><?php echo _t('workshop','help_add2');?></li>
	<li><?php echo _t('workshop','help_add3');?></li>
</ul>

<?php }
if ($todo == 'det') {
?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','det');?></p>
<ul>
	<li><?php echo _t('workshop','help_det1');?></li>
	<li><?php echo _t('workshop','help_det2');?></li>
	<li><?php echo _t('workshop','help_det4');?></li>
	<li><?php echo _t('workshop','help_det5');?></li>
	<li><?php echo _t('workshop','help_det6');?></li>
	<li><?php echo _t('workshop','help_det7');?></li>
	<li><?php echo _t('workshop','help_det8');?></li>
</ul>
<?php

  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','mod');?></p>
<ul>
	<li><?php echo _t('workshop','help_mod1');?></li>
	<li><?php echo _t('workshop','help_mod2');?></li>
	<li><?php echo _t('workshop','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','list');?></p>
<ul>
	<li><?php echo _t('workshop','help_list1');?></li>
	<li><?php echo _t('workshop','help_list2');?></li>
	<li><?php echo _t('workshop','help_list3');?></li>
	<li><?php echo _t('workshop','help_list4');?></li>
	<li><?php echo _t('workshop','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'add_u') {
        ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add_new_user');?></p>
<ul>
	<li><?php echo _t('workshop','help_add_u1');?></li>
	<li><?php echo _t('workshop','help_add_u2');?></li>
	<li><?php echo _t('workshop','help_add_u3');?></li>
	<li><?php echo _t('workshop','help_add_u4');?></li>
</ul>
        <?php }
        if ($todo == 'sup_u') {
          ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','del_user');?></p>
<ul>
	<li><?php echo _t('workshop','help_del_u1');?></li>
	<li><?php echo _t('workshop','help_del_u2');?></li>
</ul>
          <?php }
          if ($todo == 'list_cal') {
            ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','list_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_list_cal1');?></li>
	<li><?php echo _t('workshop','help_list_cal2');?></li>
	<li><?php echo _t('workshop','help_list_cal3');?></li>
</ul>
            <?php }
            if ($todo == 'mod_cal') {
              ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_add_cal1');?></li>
	<li><?php echo _t('workshop','help_add_cal2');?></li>
	<li><?php echo _t('workshop','help_add_cal3');?></li>
</ul>
              <?php }
              if ($todo == 'add_cal') {
                ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','mod_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_mod_cal1');?></li>
	<li><?php echo _t('workshop','help_mod_cal2');?></li>
	<li><?php echo _t('workshop','help_mod_cal3');?></li>
</ul>
                <?php }
                if ($todo == 'sup_cal') {
                  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_sup_cal1');?></li>
</ul>
                  <?php }
                  if ($todo == 'list_com') {
                    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','list_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_list_com1');?></li>
	<li><?php echo _t('workshop','help_list_com2');?></li>
	<li><?php echo _t('workshop','help_list_com3');?></li>
	<li><?php echo _t('workshop','help_list_com4');?></li>
</ul>
                    <?php }
                    if ($todo == 'det_com') {
                      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','det_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_det_com1');?></li>
	<li><?php echo _t('workshop','help_det_com2');?></li>
	<li><?php echo _t('workshop','help_det_com3');?></li>
	<li><?php echo _t('workshop','help_det_com4');?></li>
</ul>
                      <?php }
                      if ($todo == 'add_com') {
                        ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_add_com1');?></li>
	<li><?php echo _t('workshop','help_add_com2');?></li>
	<li><?php echo _t('workshop','help_add_com3');?></li>
</ul>
                        <?php }
                        if ($todo == 'mod_com') {
                          ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','mod_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_mod_com1');?></li>
	<li><?php echo _t('workshop','help_mod_com2');?></li>
	<li><?php echo _t('workshop','help_mod_com3');?></li>
</ul>
                          <?php }
                          if ($todo == 'sup_com') {
                            ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_sup_com1');?></li>
	<li><?php echo _t('workshop','help_sup_com2');?></li>
</ul>
<?php }
if ($todo == 'lock_com') {
?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_lock_com1');?></li>
	<li><?php echo _t('workshop','help_lock_com2');?></li>
	<li><?php echo _t('workshop','help_lock_com3');?></li>
</ul>
<?php }
if ($todo == 'sup') {
?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup');?></p>
<ul>
	<li><?php echo _t('workshop','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->

==> dl.php?src=linea21_2_8_0.zip: linea21/workshop/help.php <==
<?php
/**
 * Workshop module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\workshop
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="fa fa-life-ring" aria-hidden="true"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add');?></p>
<ul>
	<li><?php echo _t('workshop','help_add1');?></li>
	<li><?php echo _t('workshop','help_add2');?></li>
	<li><?php echo _t('workshop','help_add3');?></li>
</ul>

<?php }
if ($todo == 'det') {
?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','det');?></p>
<ul>
	<li><?php echo _t('workshop','help_det1');?></li>
	<li><?php echo _t('workshop','help_det2');?></li>
	<li><?php echo _t('workshop','help_det4');?></li>
	<li><?php echo _t('workshop','help_det5');?></li>
	<li><?php echo _t('workshop','help_det6');?></li>
	<li><?php echo _t('workshop','help_det7');?></li>
	<li><?php echo _t('workshop','help_det8');?></li>
</ul>
<?php

  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','mod');?></p>
<ul>
	<li><?php echo _t('workshop','help_mod1');?></li>
	<li><?php echo _t('workshop','help_mod2');?></li>
	<li><?php echo _t('workshop','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','list');?></p>
<ul>
	<li><?php echo _t('workshop','help_list1');?></li>
	<li><?php echo _t('workshop','help_list2');?></li>
	<li><?php echo _t('workshop','help_list3');?></li>
	<li><?php echo _t('workshop','help_list4');?></li>
	<li><?php echo _t('workshop','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'add_u') {
        ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add_new_user');?></p>
<ul>
	<li><?php echo _t('workshop','help_add_u1');?></li>
	<li><?php echo _t('workshop','help_add_u2');?></li>
	<li><?php echo _t('workshop','help_add_u3');?></li>
	<li><?php echo _t('workshop','help_add_u4');?></li>
</ul>
        <?php }
        if ($todo == 'sup_u') {
          ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','del_user');?></p>
<ul>
	<li><?php echo _t('workshop','help_del_u1');?></li>
	<li><?php echo _t('workshop','help_del_u2');?></li>
</ul>
          <?php }
          if ($todo == 'list_cal') {
            ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','list_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_list_cal1');?></li>
	<li><?php echo _t('workshop','help_list_cal2');?></li>
	<li><?php echo _t('workshop','help_list_cal3');?></li>
</ul>
            <?php }
            if ($todo == 'mod_cal') {
              ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_add_cal1');?></li>
	<li><?php echo _t('workshop','help_add_cal2');?></li>
	<li><?php echo _t('workshop','help_add_cal3');?></li>
</ul>
              <?php }
              if ($todo == 'add_cal') {
                ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','mod_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_mod_cal1');?></li>
	<li><?php echo _t('workshop','help_mod_cal2');?></li>
	<li><?php echo _t('workshop','help_mod_cal3');?></li>
</ul>
                <?php }
                if ($todo == 'sup_cal') {
                  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup_cal');?></p>
<ul>
	<li><?php echo _t('workshop','help_sup_cal1');?></li>
</ul>
                  <?php }
                  if ($todo == 'list_com') {
                    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','list_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_list_com1');?></li>
	<li><?php echo _t('workshop','help_list_com2');?></li>
	<li><?php echo _t('workshop','help_list_com3');?></li>
	<li><?php echo _t('workshop','help_list_com4');?></li>
</ul>
                    <?php }
                    if ($todo == 'det_com') {
                      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','det_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_det_com1');?></li>
	<li><?php echo _t('workshop','help_det_com2');?></li>
	<li><?php echo _t('workshop','help_det_com3');?></li>
	<li><?php echo _t('workshop','help_det_com4');?></li>
</ul>
                      <?php }
                      if ($todo == 'add_com') {
                        ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','add_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_add_com1');?></li>
	<li><?php echo _t('workshop','help_add_com2');?></li>
	<li><?php echo _t('workshop','help_add_com3');?></li>
</ul>
                        <?php }
                        if ($todo == 'mod_com') {
                          ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','mod_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_mod_com1');?></li>
	<li><?php echo _t('workshop','help_mod_com2');?></li>
	<li><?php echo _t('workshop','help_mod_com3');?></li>
</ul>
                          <?php }
                          if ($todo == 'sup_com') {
                            ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_sup_com1');?></li>
	<li><?php echo _t('workshop','help_sup_com2');?></li>
</ul>
<?php }
if ($todo == 'lock_com') {
?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup_com');?></p>
<ul>
	<li><?php echo _t('workshop','help_lock_com1');?></li>
	<li><?php echo _t('workshop','help_lock_com2');?></li>
	<li><?php echo _t('workshop','help_lock_com3');?></li>
</ul>
<?php }
if ($todo == 'sup') {
?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('workshop','sup');?></p>
<ul>
	<li><?php echo _t('workshop','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
